@@ -926,10 +926,17 @@ def rotation_matrix_from_axis(x_axis, y_axis=(0, 1, 0)):
 def rodrigues(axis, theta=None):
     """Rodrigues formula.
 
+    See: `Rodrigues' rotation formula - Wikipedia
+    <https://en.wikipedia.org/wiki/Rodrigues%27_rotation_formula>`_.
+
+    See: `Axis–angle representation - Wikipedia
+    <https://en.wikipedia.org/wiki/Axis%E2%80%93angle_representation>`_.
+
     Parameters
     ----------
     axis : numpy.ndarray or list
-        [x, y, z]
+        [x, y, z] vector.
+        You can give axis-angle representation to `axis` if `theta` is None.
     theta: float or None (optional)
         radian. If None is given, calculate theta from axis.
 
@@ -1428,6 +1435,29 @@ def axis_angle_from_matrix(rotation):
     return axis_angle_from_quaternion(quat_from_rotation_matrix(rotation))
 
 
+def angle_between_vectors(v1, v2, normalize=True):
+    """Returns the smallest angle in radians between two vectors.
+
+    Parameters
+    ----------
+    v1 : numpy.ndarray, list[float] or tuple(float)
+        input vector.
+    v2 : numpy.ndarray, list[float] or tuple(float)
+        input vector.
+    normalize : bool
+        If normalize is True, normalize v1 and v2.
+
+    Returns
+    -------
+    theta : float
+        smallest angle between v1 and v2.
+    """
+    if normalize:
+        v1 = normalize_vector(v1)
+        v2 = normalize_vector(v2)
+    return np.arccos(np.clip(np.dot(v1, v2), -1.0, 1.0))
+
+
 def random_rotation():
     """Generates a random 3x3 rotation matrix.
 
